/** 
 * 
 * Copyright 2004 Protique Ltd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.codehaus.activemq;

import org.codehaus.activemq.message.ConsumerInfo;

import javax.jms.JMSException;

/**
 * There is only meant to be a single durable subscription open for a given clientID and subscriber name;
 * this exception is thrown if a user tries to subscribe twice
 * for the same clientID and subscriber name.
 *
 * @version $Revision: 1.1 $
 */
public class DuplicateDurableSubscriptionException extends JMSException {
    private String clientID;
    private String consumerName;

    public DuplicateDurableSubscriptionException(ConsumerInfo info) {
        super("Duplicate JMS subscription for clientID: " + info.getClientId() + " and consumer: " + info.getConsumerName(), "AMQ-1000");
        this.clientID = info.getClientId();
        this.consumerName = info.getConsumerName();
    }

    public String getClientID() {
        return clientID;
    }

    public String getConsumerName() {
        return consumerName;
    }
}
