/** 
 * 
 * Copyright 2004 Protique Ltd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.codehaus.activemq.filter;

import org.codehaus.activemq.message.ActiveMQDestination;

import javax.jms.Destination;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/**
 * A {@link DestinationFilter} used for composite destinations
 *
 * @version $Revision: 1.1 $
 */
public class CompositeDestinationFilter extends DestinationFilter {
    private List filters;

    public CompositeDestinationFilter(ActiveMQDestination destination) {
        List childDestinations = destination.getChildDestinations();
        filters = new ArrayList(childDestinations.size());
        for (Iterator iter = childDestinations.iterator(); iter.hasNext();) {
            Destination childDestination = (Destination) iter.next();
            filters.add(DestinationFilter.parseFilter(childDestination));
        }
    }

    public boolean matches(Destination destination) {
        for (Iterator iter = filters.iterator(); iter.hasNext();) {
            DestinationFilter filter = (DestinationFilter) iter.next();
            if (filter.matches(destination)) {
                return true;
            }
        }
        return false;
    }

    public boolean isWildcard() {
        return true;
    }
}
