/**
 *
 * Copyright 2004 Protique Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 **/


package org.codehaus.activemq.io.impl;
import java.io.DataInput;
import java.io.IOException;
import org.codehaus.activemq.message.DurableUnsubscribe;
import org.codehaus.activemq.message.Packet;

/**
 * Reads a DurableUnsubscribe object from a Stream
 *
 * @version $Revision: 1.1 $
 */

public class DurableUnsubscribeReader extends AbstractPacketReader {

    /**
     * Return the type of Packet
     *
     * @return integer representation of the type of Packet
     */

    public int getPacketType() {
        return Packet.DURABLE_UNSUBSCRIBE;
    }

    /**
     * @return a new Packet instance
     */

    public Packet createPacket() {
        return new DurableUnsubscribe();
    }


    /**
     * build a Packet instance from the data input stream
     *
     * @param packet A Packet object
     * @param dataIn the data input stream to build the packet from
     * @throws IOException
     */

    public void buildPacket(Packet packet, DataInput dataIn) throws IOException {
        super.buildPacket(packet, dataIn);
        DurableUnsubscribe ds = (DurableUnsubscribe) packet;
        ds.setClientId(dataIn.readUTF());
        ds.setSubscriberName(dataIn.readUTF());
    }


}
