/** 
 * 
 * Copyright 2004 Protique Ltd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/

package org.codehaus.activemq.io.impl;
import java.io.DataInput;
import java.io.IOException;
import org.codehaus.activemq.message.Packet;

/**
 * Allows instances implementing Packet to read from a DataOutputStream
 */

public interface PacketReader {

    /**
     * Return the type of Packet
     * 
     * @return integer representation of the type of Packet
     */

    public int getPacketType();

    /**
     * @param packetType
     * @return true if this PacketReader can a Packet of this type
     */
    public boolean canRead(int packetType);

    /**
     * @return a new Packet instance
     */

    public Packet createPacket();

    /**
     * build a Packet instance from the data input stream
     *
     * @param packet A Packet object
     * @param dataIn the data input stream to build the packet from
     * @throws IOException
     */

    public void buildPacket(Packet packet, DataInput dataIn) throws IOException;

    /**
     * Deserailizes a Packet from a byte array
     *
     * @param data
     * @return the deserialized Packet
     * @throws IOException
     */

    public Packet readPacketFromByteArray(byte[] data) throws IOException;
    
    /**
     * Set the wire format version
     * @param version
     */
    public void setWireFormatVersion(int version);
    
    /**
     * @return the wire format version
     */
    public int getWireFormatVersion();


}