/**
 *
 * Copyright 2004 Protique Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 **/


package org.codehaus.activemq.io.impl;
import java.io.DataInput;
import java.io.IOException;
import org.codehaus.activemq.message.Packet;
import org.codehaus.activemq.message.ResponseReceipt;

/**
 * Reads a ConsumerInfo object from a Stream
 */

public class ResponseReceiptReader extends ReceiptReader {

    /**
     * Return the type of Packet
     *
     * @return integer representation of the type of Packet
     */
    public int getPacketType() {
        return Packet.RESPONSE_RECEIPT_INFO;
    }

    /**
     * @return a new Packet instance
     */

    public Packet createPacket() {
        return new ResponseReceipt();
    }


    /**
     * build a Packet instance from the data input stream
     *
     * @param packet A Packet object
     * @param dataIn the data input stream to build the packet from
     * @throws IOException
     */

    public void buildPacket(Packet packet, DataInput dataIn) throws IOException {
        super.buildPacket(packet, dataIn);
        ResponseReceipt info = (ResponseReceipt) packet;
        int size = dataIn.readInt();
        byte data[] = null;
        if (size != 0) {
            data = new byte[size];
            dataIn.readFully(data);
        }
        info.setResultBytes(data);
    }


}
