/** 
 * 
 * Copyright 2004 Protique Ltd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.codehaus.activemq.management;

import EDU.oswego.cs.dl.util.concurrent.CopyOnWriteArrayList;
import org.codehaus.activemq.ActiveMQConnection;
import org.codehaus.activemq.util.IndentPrinter;

import javax.management.j2ee.statistics.JMSConnectionStats;
import javax.management.j2ee.statistics.JMSStats;
import java.util.List;

/**
 * Statistics for a number of JMS connections
 *
 * @version $Revision: 1.1 $
 */
public class JMSStatsImpl extends StatsImpl implements JMSStats {
    private List connections = new CopyOnWriteArrayList();

    public JMSStatsImpl() {
    }

    public JMSConnectionStats[] getConnections() {
        Object[] connectionArray = connections.toArray();
        int size = connectionArray.length;
        JMSConnectionStats[] answer = new JMSConnectionStats[size];
        for (int i = 0; i < size; i++) {
            ActiveMQConnection connection = (ActiveMQConnection) connectionArray[i];
            answer[i] = connection.getConnectionStats();
        }
        return answer;
    }

    public void addConnection(ActiveMQConnection connection) {
        connections.add(connection);
    }

    public void removeConnection(ActiveMQConnection connection) {
        connections.remove(connection);
    }

    public void dump(IndentPrinter out) {
        out.printIndent();
        out.println("factory {");
        out.incrementIndent();
        JMSConnectionStats[] array = getConnections();
        for (int i = 0; i < array.length; i++) {
            JMSConnectionStatsImpl connectionStat = (JMSConnectionStatsImpl) array[i];
            connectionStat.dump(out);
        }
        out.decrementIndent();
        out.printIndent();
        out.println("}");
        out.flush();
    }
}
