/** 
 * 
 * Copyright 2004 Protique Ltd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/

package org.codehaus.activemq.service;

import javax.jms.JMSException;

/**
 * <p><code>Service</code> represents some service of some kind with a simple start/stop lifecycle.</p>
 * <b>Note</b> that usually once a service has been stopped it should be discarded and a new service
 * instance created again.
 *
 * @version $Revision: 1.1 $
 */
public interface Service {

    /**
     * Called to start the service
     *
     * @throws JMSException
     */
    public void start() throws JMSException;

    /**
     * Called to shutdown the service
     *
     * @throws JMSException
     */
    public void stop() throws JMSException;

}
