/** 
 * 
 * Copyright 2004 Hiram Chirino
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.codehaus.activemq.service;

import org.codehaus.activemq.broker.Broker;

import javax.transaction.xa.XAException;
import java.io.Serializable;


/**
 * A Transaction keeps track of all the tasks
 * that must be run before and after transactional events.
 *
 * @version $Revision: 1.1 $
 */
public interface Transaction extends Serializable {

    public void addPrePrepareTask(TransactionTask task);

    public void addPostCommitTask(TransactionTask task);

    public void addPostRollbackTask(TransactionTask task);

    public void commit(boolean onePhase) throws XAException;

    public void rollback() throws XAException;

    public int prepare() throws XAException;

    /**
     * Called when this transaction has been recovered from disk
     * to re-associate it with the broker in which its being applied.
     *
     * @param broker
     */
    public void setBroker(Broker broker);
}