/** 
 * 
 * Copyright 2004 Hiram Chirino
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.codehaus.activemq.service;

import org.codehaus.activemq.broker.BrokerClient;
import org.codehaus.activemq.message.ActiveMQXid;

import javax.jms.JMSException;
import javax.transaction.xa.XAException;

/**
 * A Transaction keeps track of all the tasks
 * that must be run before and after transactional events.
 *
 * @version $Revision: 1.1 $
 */
public interface TransactionManager extends Service {

    public void setContexTransaction(Transaction tx);

    public Transaction getContexTransaction();

    public Transaction createLocalTransaction(BrokerClient client, String txid) throws JMSException;

    public Transaction getLocalTransaction(String txid) throws JMSException;

    public Transaction createXATransaction(BrokerClient client, ActiveMQXid xid) throws XAException;

    public Transaction getXATransaction(ActiveMQXid xid) throws XAException;

    public ActiveMQXid[] getPreparedXATransactions() throws XAException;

    /**
     * A hint to the TransactionManager that an BrokerClient has stopped
     * This enables the TransactionManager to rollback in progess transactions
     * that the client created.
     *
     * @param client
     */
    public void cleanUpClient(BrokerClient client) throws JMSException;


    /**
     * Called on restart when recovering prepared transactions to reload
     * a transaction from persistent store
     *
     * @param xid
     * @param transaction
     */
    public void loadTransaction(ActiveMQXid xid, Transaction transaction) throws XAException;
}