/** 
 * 
 * Copyright 2004 Protique Ltd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.codehaus.activemq.transport;
import java.util.Iterator;
import EDU.oswego.cs.dl.util.concurrent.*;

/**
 * A useful base class for {@link DiscoveryAgent} implementations
 *
 * @version $Revision: 1.2 $
 */
public abstract class DiscoveryAgentSupport implements DiscoveryAgent {
    protected CopyOnWriteArrayList listeners = new CopyOnWriteArrayList();

    /**
     * Add a discovery listener
     * @param listener
     */
    public void addDiscoveryListener(DiscoveryListener listener){
        listeners.add(listener);
    }
    
    /**
     * remove a discovery listener
     * @param listener
     */
    public void removeDiscoveryListener(DiscoveryListener listener){
        listeners.remove(listener);
    }

    protected void fireAddService(DiscoveryEvent event){
        for(Iterator i = listeners.iterator(); i.hasNext();){
            DiscoveryListener l = (DiscoveryListener)i.next();
            l.addService(event);
        }
    }
    
    protected void fireRemoveService(DiscoveryEvent event){
        for(Iterator i = listeners.iterator(); i.hasNext();){
            DiscoveryListener l = (DiscoveryListener)i.next();
            l.removeService(event);
        }
    }

}
