/** 
 * 
 * Copyright 2004 Protique Ltd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/

package org.codehaus.activemq.transport.remote;
import java.net.URI;
import javax.jms.JMSException;
import org.codehaus.activemq.io.WireFormat;
import org.codehaus.activemq.transport.TransportChannel;
import org.codehaus.activemq.transport.composite.CompositeTransportChannelFactory;
import org.codehaus.activemq.transport.peer.PeerTransportChannelFactory;

/**
 * Creates a remote based transport.
 * 
 * @see RemoteTransportChannel
 * @version $Revision: 1.1 $
 */
public class RemoteTransportChannelFactory extends CompositeTransportChannelFactory {
    /**
     * Create a Channel
     * 
     * @param wireFormat
     * @param remoteLocation
     * @return the TransportChannel bound to the remote node
     * @throws JMSException
     */
    public TransportChannel create(WireFormat wireFormat, URI remoteLocation) throws JMSException {
        TransportChannel result = new RemoteTransportChannel(wireFormat, stripLeadingSlashes(remoteLocation.getSchemeSpecificPart()));
        return populateProperties(result, remoteLocation);
    }
    
    /**
     * Create a peer channel
     * @param wireFormat
     * @param remoteLocation
     * @param localLocation
     * @return
     * @throws JMSException
     * 
     */
    
    public TransportChannel create(WireFormat wireFormat, URI remoteLocation, URI localLocation) throws JMSException {
        RemoteTransportChannel result = new RemoteTransportChannel(wireFormat, remoteLocation.getSchemeSpecificPart());
        result.setBrokerConnectorURI(localLocation.toString());
        return populateProperties(result, remoteLocation);
    }

    
    /**
     * Does this channel require an embedded broker to perform such as VM or multicast based transports
     * 
     * @return true if an embedded broker is a requirement of using the channel
     */
    public boolean requiresEmbeddedBroker() {
        return true;
    }
}