/** 
 * 
 * Copyright 2004 Hiram Chirino
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.codehaus.activemq;

import javax.jms.Connection;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageConsumer;
import javax.jms.MessageProducer;
import javax.jms.Queue;
import javax.jms.Session;
import javax.jms.TextMessage;

import junit.framework.TestCase;

import org.codehaus.activemq.message.ActiveMQDestination;

/**
 * @version $Revision: 1.1 $
 */
public class BrokerAdminCommandsTest extends TestCase {

	private Connection connection;

    protected void setUp() throws Exception {
		 ActiveMQConnectionFactory factory = new ActiveMQConnectionFactory("vm://localhost");
		 connection = factory.createConnection();
		 connection.start();
    }

    /**
     * @see junit.framework.TestCase#tearDown()
     */
    protected void tearDown() throws Exception {
		 connection.close();
    }

    
    /**
     * @throws JMSException
     */
    public void testStoppedConsumerHoldsMessagesTillStarted() throws JMSException {
        
         Session startedSession = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);

		 // Setup the consumers.
		 Queue queue = startedSession.createQueue("testQueue");

		 // Send the message.
		 MessageProducer producer = startedSession.createProducer(queue);		 
		 TextMessage message = startedSession.createTextMessage("First");
		 producer.send(message);
		 
		 // This should remove all the messages that were sent to the destination.
		 ((ActiveMQConnection)connection).destroyDestination((ActiveMQDestination)queue);
		 
		 message.setText("Second");
		 producer.send(message);
		 
		 // Test the assertions.
		 MessageConsumer startedConsumer = startedSession.createConsumer(queue);
		 Message m = startedConsumer.receive(1000);
		 assertNotNull(m);
		 
		 assertEquals( "Second", ((TextMessage)m).getText() );
    }
  
}