/** 
 * 
 * Copyright 2004 Protique Ltd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.codehaus.activemq;

import org.codehaus.activemq.util.IndentPrinter;

import javax.jms.Connection;
import javax.jms.DeliveryMode;
import javax.jms.JMSException;
import javax.jms.MessageConsumer;
import javax.jms.Session;
import javax.jms.Topic;

/**
 * @version $Revision: 1.1 $
 */
public class JmsTopicSendReceiveTest extends JmsSendReceiveTestSupport {
    protected Connection connection;

    protected void setUp() throws Exception {
        super.setUp();

        connectionFactory = createConnectionFactory();
        connection = createConnection();
        if (durable) {
            connection.setClientID(getClass().getName());
        }

        System.out.println("Created connection: " + connection);

        session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);

        System.out.println("Created session: " + session);
        producer = session.createProducer(null);
        producer.setDeliveryMode(deliveryMode);

        System.out.println("Created producer: " + producer + " delivery mode = " +
                (deliveryMode == DeliveryMode.PERSISTENT ? "PERSISTENT" : "NON_PERSISTENT"));

        if (topic) {
            consumerDestination = session.createTopic(getConsumerSubject());
            producerDestination = session.createTopic(getProducerSubject());
        }
        else {
            consumerDestination = session.createQueue(getConsumerSubject());
            producerDestination = session.createQueue(getProducerSubject());
        }

        System.out.println("Created  consumer destination: " + consumerDestination + " of type: " + consumerDestination.getClass());
        System.out.println("Created  producer destination: " + producerDestination + " of type: " + producerDestination.getClass());
        consumer = createConsumer();
        consumer.setMessageListener(this);
        connection.start();

        System.out.println("Created connection: " + connection);
    }

    protected MessageConsumer createConsumer() throws JMSException {
        if (durable) {
            System.out.println("Creating durable consumer");
            return session.createDurableSubscriber((Topic) consumerDestination, getName());
        }
        return session.createConsumer(consumerDestination);
    }

    protected void tearDown() throws Exception {
        System.out.println("Dumping stats...");
        connectionFactory.getFactoryStats().dump(new IndentPrinter());

        System.out.println("Closing down connection");

        /** TODO we should be able to shut down properly */
        session.close();
        connection.close();
    }

}