/** 
 * 
 * Copyright 2004 Protique Ltd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.codehaus.activemq.service;

import org.codehaus.activemq.broker.BrokerClientStub;
import org.codehaus.activemq.message.ActiveMQMessage;
import org.codehaus.activemq.message.ConsumerInfo;

import java.util.List;

/**
 * @version $Revision: 1.1 $
 */
public class SimpleTopicBrokerTest extends BrokerTestSupport {

    protected BrokerClientStub client = new BrokerClientStub();
    protected ConsumerInfo consumerInfo;


    public void testDispatch() throws Exception {
        // now lets dispatch a message
        ActiveMQMessage message = createMessage(getDestination());

        List messages = client.flushMessages();
        assertEquals("No messages received yet", 0, messages.size());

        // now lets send it
        broker.sendMessage(client, message);

        client.waitForMessageToArrive();

        // now the message should be here
        messages = client.flushMessages();
        assertEquals("Expected a single message", 1, messages.size());

        System.out.println("Received message: " + messages.get(0));
    }

    protected String getDestination() {
        return getClass().getName() + "." + getName();
    }

    protected void setUp() throws Exception {
        super.setUp();
        consumerInfo = createConsumer(getDestination());
        broker.addMessageConsumer(client, consumerInfo);
    }

    protected void tearDown() throws Exception {
        if (broker != null && client != null && consumerInfo != null) {
            broker.removeMessageConsumer(client, consumerInfo);
        }
        super.tearDown();
    }
}
