/**
 * 
 * Copyright 2004 Protique Ltd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.codehaus.activemq.test;

import javax.jms.Connection;
import javax.jms.DeliveryMode;
import javax.jms.Session;

import org.codehaus.activemq.ActiveMQConnectionFactory;


/**
 * @version $Revision: 1.3 $
 */
public class JmsTopicSendReceiveWithTwoConnectionsTest extends JmsSendReceiveTestSupport {

    protected Connection sendConnection;
    protected Connection receiveConnection;
    protected Session receiveSession;

    protected void setUp() throws Exception {
        super.setUp();

        connectionFactory = createConnectionFactory();

        sendConnection = createSendConnection();
        sendConnection.start();

        receiveConnection = createReceiveConnection();
        receiveConnection.start();

        System.out.println("Created sendConnection: " + sendConnection);
        System.out.println("Created receiveConnection: " + receiveConnection);

        session = sendConnection.createSession(false, Session.AUTO_ACKNOWLEDGE);
        receiveSession = receiveConnection.createSession(false, Session.AUTO_ACKNOWLEDGE);

        System.out.println("Created sendSession: " + session);
        System.out.println("Created receiveSession: " + receiveSession);

        producer = session.createProducer(null);
        producer.setDeliveryMode(deliveryMode);

        System.out.println("Created producer: " + producer + " delivery mode = " +
                (deliveryMode == DeliveryMode.PERSISTENT ? "PERSISTENT" : "NON_PERSISTENT"));

        if (topic) {
            consumerDestination = session.createTopic(getConsumerSubject());
            producerDestination = session.createTopic(getProducerSubject());
        }
        else {
            consumerDestination = session.createQueue(getConsumerSubject());
            producerDestination = session.createQueue(getProducerSubject());
        }

        System.out.println("Created  consumer destination: " + consumerDestination + " of type: " + consumerDestination.getClass());
        System.out.println("Created  producer destination: " + producerDestination + " of type: " + producerDestination.getClass());

        consumer = receiveSession.createConsumer(consumerDestination);
        consumer.setMessageListener(this);


        System.out.println("Started connections");
    }

    protected Connection createReceiveConnection() throws Exception {
        return createConnection();
    }

    protected Connection createSendConnection() throws Exception {
        return createConnection();
    }

    protected ActiveMQConnectionFactory createConnectionFactory() throws Exception {
        return new ActiveMQConnectionFactory("vm://localhost");
    }

    protected void tearDown() throws Exception {
        session.close();
        receiveSession.close();
        sendConnection.close();
        receiveConnection.close();
    }
}