/** 
 * 
 * Copyright 2004 Protique Ltd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.codehaus.activemq.ra;

/**
 * A helper class used to provide access to the current active
 * {@link SessionAndProducer} instance being used to process a message
 * in the current thread so that messages can be produced using the same
 * session.
 *
 * @version $Revision: 1.1 $
 */
public class SessionAndProducerHelper {
    private static final ThreadLocal threadLocal = new ThreadLocal();

    /**
     * Returns the current {@link SessionAndProducer} used by the current thread which is processing a message.
     * This allows us to access the current Session to send a message using the same underlying
     * session to avoid unnecessary XA or to use regular JMS transactions while using message driven POJOs.
     *
     * @return
     */
    public static SessionAndProducer getActiveSessionAndProducer() {
        return (SessionAndProducer) threadLocal.get();
    }


    /**
     * Registers the session and producer which should be called before the
     * {@link javax.resource.spi.endpoint.MessageEndpoint#beforeDelivery(java.lang.reflect.Method)}
     * method is called.
     *
     * @param sessionAndProducer
     */
    public static void register(SessionAndProducer sessionAndProducer) {
        threadLocal.set(sessionAndProducer);
    }

    /**
     * Unregisters the session and producer which should be called after the
     * {@link javax.resource.spi.endpoint.MessageEndpoint#afterDelivery()}
     * method is called.
     *
     * @param sessionAndProducer
     */
    public static void unregister(SessionAndProducer sessionAndProducer) {
        threadLocal.set(null);
    }
}
