/** 
 * 
 * Copyright 2004 Michael Gaffney
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.codehaus.activemq.ra;

import junit.framework.TestCase;

/**
 * @version $Revision: 1.1 $
 */
public class ActiveMQResourceAdapterJavaBeanEqualityTest extends TestCase {

    private ActiveMQResourceAdapter raOne;
    private ActiveMQResourceAdapter raTwo;

    public ActiveMQResourceAdapterJavaBeanEqualityTest(String name) {
        super(name);
    }

    protected void setUp() throws Exception {
        super.setUp();
        raOne = new ActiveMQResourceAdapter();        
        raTwo = new ActiveMQResourceAdapter();
    }

    public void testSelfEquality() {
        assertEquality(raOne, raOne);        
    }
    
    public void testEmptyEquality() {
        assertEquality(raOne, raTwo);
    }

    public void testNullEqualityFailure() {
        assertFalse(raOne.equals(null));
    }

    public void testEndpointWorkerTypeEquality() {
        raOne.setEndpointWorkerType("asf");
        raTwo.setEndpointWorkerType("asf");
        assertEquality(raOne,raTwo);
    }

    public void testEndpointWorkerTypeEqualityDifferentCase() {
        raOne.setEndpointWorkerType("ASF");
        raTwo.setEndpointWorkerType("asf");
        assertEquality(raOne,raTwo);
    }

    public void testEndpointWorkerTypeInequality() {
        raOne.setEndpointWorkerType("asf");
        raTwo.setEndpointWorkerType("polling");
        assertNonEquality(raOne,raTwo);
    }

    public void testClientIdEquality() {
        raOne.setClientid("one");
        raTwo.setClientid("one");
        assertEquality(raOne,raTwo);
    }

    public void testClientIdInequality() {
        raOne.setClientid("one");
        raTwo.setClientid("two");
        assertNonEquality(raOne,raTwo);
    }

    public void testClientIdInequalityDifferentCase() {
        raOne.setClientid("one");
        raTwo.setClientid("ONE");
        assertNonEquality(raOne, raTwo);
    }

    public void testNullClientIdInequality() {
        raOne.setClientid("one");
        raTwo.setClientid(null);
        assertNonEquality(raOne, raTwo);
    }

    public void testServerUrlEquality() {
        raOne.setServerUrl("one");
        raTwo.setServerUrl("one");
        assertEquality(raOne,raTwo);
    }

    public void testServerUrlInequality() {
        raOne.setServerUrl("one");
        raTwo.setServerUrl("two");
        assertNonEquality(raOne,raTwo);
    }

    public void testServerUrlInequalityDifferentCase() {
        raOne.setServerUrl("one");
        raTwo.setServerUrl("ONE");
        assertNonEquality(raOne, raTwo);
    }

    public void testNullServerUrlInequality() {
        raOne.setServerUrl("one");
        raTwo.setServerUrl(null);
        assertNonEquality(raOne, raTwo);
    }

    public void testUserNameEquality() {
        raOne.setUserName("one");
        raTwo.setUserName("one");
        assertEquality(raOne, raTwo);
    }

    public void testUserNameInequality() {
        raOne.setUserName("one");
        raTwo.setUserName("two");
        assertNonEquality(raOne, raTwo);
    }

    public void testUserNameInequalityDifferentCase() {
        raOne.setUserName("one");
        raTwo.setUserName("ONE");
        assertNonEquality(raOne, raTwo);
    }

    public void testNullUserNameInequality() {
        raOne.setUserName("one");
        raTwo.setUserName(null);
        assertNonEquality(raOne, raTwo);
    }
    
    public void testPasswordNotPartOfEquality() {
        raOne.setClientid("one");
        raTwo.setClientid("one");
        raOne.setPassword("foo");
        raTwo.setPassword("bar");
        assertEquality(raOne, raTwo);
    }

    private void assertEquality(ActiveMQResourceAdapter leftRa, ActiveMQResourceAdapter rightRa) {
        assertTrue("ActiveMQResourceAdapters are not equal", leftRa.equals(rightRa));
        assertTrue("ActiveMQResourceAdapters are not equal", rightRa.equals(leftRa));
        assertTrue("HashCodes are not equal", leftRa.hashCode() == rightRa.hashCode());
    }

    private void assertNonEquality(ActiveMQResourceAdapter leftRa, ActiveMQResourceAdapter rightRa) {
        assertFalse("ActiveMQResourceAdapters are equal", leftRa.equals(rightRa));
        assertFalse("ActiveMQResourceAdapters are equal", rightRa.equals(leftRa));
        assertFalse("HashCodes are equal", leftRa.hashCode() == rightRa.hashCode());
    }

    
}
