/**
 * Redistribution and use of this software and associated documentation
 * ("Software"), with or without modification, are permitted provided
 * that the following conditions are met:
 *
 * 1. Redistributions of source code must retain copyright
 *    statements and notices.  Redistributions must also contain a
 *    copy of this document.
 *
 * 2. Redistributions in binary form must reproduce the
 *    above copyright notice, this list of conditions and the
 *    following disclaimer in the documentation and/or other
 *    materials provided with the distribution.
 *
 * 3. The name "Exolab" must not be used to endorse or promote
 *    products derived from this Software without prior written
 *    permission of Exoffice Technologies.  For written permission,
 *    please contact jima@intalio.com.
 *
 * 4. Products derived from this Software may not be called "Exolab"
 *    nor may "Exolab" appear in their names without prior written
 *    permission of Exoffice Technologies. Exolab is a registered
 *    trademark of Exoffice Technologies.
 *
 * 5. Due credit should be given to the Exolab Project
 *    (http://www.exolab.org/).
 *
 * THIS SOFTWARE IS PROVIDED BY EXOFFICE TECHNOLOGIES AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
 * EXOFFICE TECHNOLOGIES OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Copyright 2001, 2003 (C) Exoffice Technologies Inc. All Rights Reserved.
 *
 * $Id: ActiveMQProvider.java,v 1.1 2004/08/12 11:00:31 jstrachan Exp $
 */
package org.exolab.jmscts.activemq;

import org.exolab.jmscts.provider.Administrator;
import org.exolab.jmscts.provider.Provider;

import javax.jms.JMSException;


/**
 * This class enables test cases to be run against the ActiveQ provider
 *
 * @author <a href="mailto:james@protique.com">James Strahcan</a>
 * @version $Revision: 1.1 $ $Date: 2004/08/12 11:00:31 $
 * @see org.exolab.jmscts.activemq.ActiveMQAdministrator
 */
public class ActiveMQProvider implements Provider {

    /**
     * The administration interface
     */
    private ActiveMQAdministrator _admin = new ActiveMQAdministrator();

    /**
     * Construct an instance of the interface to the SonicMQ provider
     */
    public ActiveMQProvider() {
    }

    /**
     * Initialises the administation interface
     *
     * @throws JMSException if the administration interface can't be
     *                      initialised
     */
    public void initialise(boolean start) throws JMSException {
        _admin.initialise();
    }

    /**
     * Returns the administration interface
     */
    public Administrator getAdministrator() {
        return _admin;
    }

    /**
     * This method cleans up the administrator
     */
    public void cleanup(boolean stop) {
        _admin.cleanup();
        _admin = null;
    }

}
