/** 
 * 
 * Copyright 2004 Protique Ltd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.codehaus.activemq.transport.ember;

import org.codehaus.activemq.io.WireFormat;
import org.codehaus.activemq.transport.TransportServerChannel;
import org.codehaus.activemq.transport.TransportServerChannelFactory;
import pyrasun.eio.EIOGlobalContext;
import pyrasun.eio.EIOPoolingStrategy;
import pyrasun.eio.services.EmberServiceController;
import pyrasun.eio.services.bytearray.ByteArrayServerService;

import javax.jms.JMSException;
import java.io.IOException;
import java.net.URI;

/**
 * An EmberIO (using NIO) implementation of a TransportServerChannelFactory
 * 
 * @version $Revision: 1.2 $
 */
public class EmberTransportServerChannelFactory extends EmberSupport implements TransportServerChannelFactory {

    private EIOPoolingStrategy acceptPoolingStrategy;
    private String acceptPoolingStrategyName = "BLOCKING_ACCEPTOR";

    public EmberTransportServerChannelFactory() {
    }

    public EmberTransportServerChannelFactory(EIOGlobalContext context, EIOPoolingStrategy ioPoolingStrategy, EIOPoolingStrategy acceptPoolingStrategy) {
        super(context, ioPoolingStrategy);
        this.acceptPoolingStrategy = acceptPoolingStrategy;
    }

    /**
     * Bind a ServerChannel to an address
     *
     * @param wireFormat
     * @param bindAddress
     * @return the TransportChannel bound to the remote node
     * @throws JMSException
     */
    public TransportServerChannel create(WireFormat wireFormat, URI bindAddress) throws JMSException {
        try {
            EmberServiceController controller = getController();
            ByteArrayServerService service = new ByteArrayServerService(getContext(), getAcceptPoolingStrategy(), getIoPoolingStrategy(), bindAddress.getHost(), bindAddress.getPort());
            controller.addService(service);

            EmberTransportServerChannel answer = new EmberTransportServerChannel(wireFormat, bindAddress, getContext(), controller);
            service.setListener(answer);
            return answer;
        }
        catch (IOException e) {
            throw createJMSException("Initialization of TransportServerChannel failed: ", e);
        }
    }

    protected EIOPoolingStrategy getAcceptPoolingStrategy() {
        if (acceptPoolingStrategy == null) {
            acceptPoolingStrategy = getPoolingStrategyByName(acceptPoolingStrategyName);
        }
        return acceptPoolingStrategy;
    }
}