/**
 *
 * Copyright 2004 Hiram Chirino
 * Copyright 2004 Protique Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 **/
package org.codehaus.activemq.transport.gnet;

import org.apache.geronimo.network.SelectorManager;
import org.apache.geronimo.pool.ClockPool;
import org.apache.geronimo.pool.ThreadPool;
import org.codehaus.activemq.io.WireFormat;
import org.codehaus.activemq.transport.TransportServerChannel;
import org.codehaus.activemq.transport.TransportServerChannelFactory;

import javax.jms.JMSException;
import java.net.URI;

/**
 * An implementation of a TransportServerChannelFactory which uses
 * the Geronimo network layer for connectivity.
 *
 * @version $Revision: 1.2 $
 */
public class GTransportServerChannelFactory implements TransportServerChannelFactory {

    private static ThreadPool threadPool;
    private static ClockPool clockPool;
    private static SelectorManager selectorManager;

    static public void init(SelectorManager sm, ThreadPool tp,
                            ClockPool cp) throws IllegalArgumentException {

        if (sm == null || tp == null || cp == null) {
            throw new IllegalArgumentException();
        }

        selectorManager = sm;
        threadPool = tp;
        clockPool = cp;
    }

    static private void init() throws Exception {

        // Don't init if allready done.
        if (threadPool != null) {
            return;
        }

        threadPool = new ThreadPool();
        threadPool.setKeepAliveTime(1 * 1000);
        threadPool.setPoolSize(5);
        threadPool.setPoolName("S Pool");

        clockPool = new ClockPool();
        clockPool.setPoolName("S Clock");

        selectorManager = new SelectorManager();
        selectorManager.setThreadPool(threadPool);
        selectorManager.setThreadName("S Manager");
        selectorManager.setTimeout(1000);

        threadPool.doStart();
        clockPool.doStart();
        selectorManager.doStart();

    }

    /**
     * Bind a ServerChannel to an address
     *
     * @param wireFormat
     * @param bindAddress
     * @return the TransportChannel bound to the remote node
     * @throws JMSException
     */
    public TransportServerChannel create(WireFormat wireFormat, URI bindAddress) throws JMSException {
        try {
            init();
            return new GTransportServerChannel(wireFormat, bindAddress, selectorManager, threadPool, clockPool);
        }
        catch (Exception e) {
            e.printStackTrace();
            JMSException ex = new JMSException(e.getMessage());
            ex.setLinkedException(e);
            throw ex;
        }
    }

}