/** 
 * 
 * Copyright 2004 Protique Ltd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.codehaus.activemq.transport.http;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.codehaus.activemq.io.TextWireFormat;
import org.codehaus.activemq.io.WireFormat;
import org.codehaus.activemq.transport.TransportChannel;
import org.codehaus.activemq.transport.TransportChannelFactorySupport;
import org.codehaus.activemq.transport.xstream.XStreamWireFormat;
import org.codehaus.activemq.util.JMSExceptionHelper;

import javax.jms.JMSException;
import java.net.MalformedURLException;
import java.net.URI;
import java.net.URISyntaxException;

/**
 * @version $Revision: 1.2 $
 */
public class HttpTransportChannelFactory extends TransportChannelFactorySupport {
    private static final Log log = LogFactory.getLog(HttpTransportChannelFactory.class);

    public TransportChannel create(WireFormat wireFormat, URI remoteLocation) throws JMSException {
        try {
            return create(wireFormat, remoteLocation, new URI("http://localhost:0"));
        }
        catch (URISyntaxException e) {
            throw JMSExceptionHelper.newJMSException(e.getMessage(), e);
        }
    }

    public TransportChannel create(WireFormat wireFormat, URI remoteLocation, URI localLocation) throws JMSException {
        try {
            HttpTransportChannel channel = new HttpTransportChannel(asTextWireFormat(wireFormat), remoteLocation.toString());
            return populateProperties(channel, remoteLocation);
        }
        catch (MalformedURLException e) {
            throw JMSExceptionHelper.newJMSException(e.getMessage(), e);
        }
    }

    protected TextWireFormat asTextWireFormat(WireFormat wireFormat) {
        if (wireFormat instanceof TextWireFormat) {
            return (TextWireFormat) wireFormat;
        }
        log.trace("Not created with a TextWireFromat: " + wireFormat);
        return new XStreamWireFormat();
    }

    public boolean requiresEmbeddedBroker() {
        return false;
    }

}
